@@ -3,20 +3,30 @@
 This module contains the logic to convert an AWS intrinsic function/conditional to
 it's Terraform equivalent.
 """
+
 import logging
 import re
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Union
 
 import cf2tf.convert
+import cf2tf.terraform.blocks as hcl2
 import cf2tf.terraform.doc_file as doc_file
-import cf2tf.terraform.hcl2 as hcl2
+from cf2tf.terraform.hcl2.custom import LiteralType
+from cf2tf.terraform.hcl2.primitive import NullType, StringType, TerraformType
 
 if TYPE_CHECKING:
     from cf2tf.convert import TemplateConverter
 
 log = logging.getLogger("cf2tf")
 
-Dispatch = Dict[str, Callable[..., Any]]
+Instrinsic_Converter = Callable[["TemplateConverter", Any], TerraformType]
+
+Pseduo_Resolver = Callable[["TemplateConverter"], TerraformType]
+
+Pseduo_Dispatch = Dict[str, Pseduo_Resolver]
+
+Dispatch = Dict[str, Instrinsic_Converter]
+
 
 # todo Most of these exceptions are very similar
 # either we expect a certain type and didnt get it.
@@ -43,8 +53,7 @@ def base64(_tc: "TemplateConverter", value: Any):
             f"Fn::Base64 - The value must be a String, not {type(value).__name__}."
         )
 
-    value = value.strip('"')
-    return f"base64encode({value})"
+    return LiteralType(f"base64encode({value})")
 
 
 def cidr(_tc: "TemplateConverter", values: Any):
@@ -75,7 +84,7 @@ def cidr(_tc: "TemplateConverter", values: Any):
             )
         )
 
-    ip_block: str = values[0].strip('"')
+    ip_block: str = values[0]
     count = int(values[1])
     hostBits = int(values[2])
 
@@ -85,7 +94,9 @@ def cidr(_tc: "TemplateConverter", values: Any):
 
     newbits = mask - int(netmask)
 
-    return f'cidrsubnets("{ip_block}", {", ".join([str(newbits)] * count)})'
+    return LiteralType(
+        f'cidrsubnets("{ip_block}", {", ".join([str(newbits)] * count)})'
+    )
 
 
 def and_(_tc: "TemplateConverter", values: Any):
@@ -113,7 +124,7 @@ def and_(_tc: "TemplateConverter", values: Any):
     if len_ < 2 or len_ > 10:
         raise ValueError("Fn::And - The values must have between 2 and 10 conditions.")
 
-    return f"alltrue({values})"
+    return LiteralType(f"alltrue({values})")
 
 
 def equals(_tc: "TemplateConverter", values: Any):
@@ -139,7 +150,7 @@ def equals(_tc: "TemplateConverter", values: Any):
     if not len(values) == 2:
         raise ValueError("Fn::Equals - The values must contain two values to compare.")
 
-    return f"{values[0]} == {values[1]}"
+    return LiteralType(f"{values[0]} == {values[1]}")
 
 
 def if_(_tc: "TemplateConverter", values: Any):
@@ -181,7 +192,7 @@ def if_(_tc: "TemplateConverter", values: Any):
 
     condition = condition.strip('"')
 
-    return f"local.{condition} ? {values[1]} : {values[2]}"
+    return LiteralType(f"local.{condition} ? {values[1]} : {values[2]}")
 
 
 def not_(_tc: "TemplateConverter", values: Any):
@@ -210,7 +221,7 @@ def not_(_tc: "TemplateConverter", values: Any):
     condition: Any = values[0]
 
     # todo This needs fixed because python True needs to be terraform true
-    return f"!{condition}"
+    return LiteralType(f"!{condition}")
 
 
 def or_(_tc: "TemplateConverter", values: Any):
@@ -241,7 +252,10 @@ def or_(_tc: "TemplateConverter", values: Any):
     # todo This isnt really correct. We need a way to convert a python
     # data object into a valid terraform argument value, which includes proper quoting
     # and maybe even indentation
-    return f"anytrue({values})"
+
+    values = _terraform_list(values)
+
+    return LiteralType(f"anytrue({values})")
 
 
 def condition(template: "TemplateConverter", name: Any):
@@ -263,14 +277,16 @@ def condition(template: "TemplateConverter", name: Any):
             f"Fn::Condition - The value must be a String, not {type(name).__name__}."
         )
 
+    # This is a side effect of how we handle StringType
     name = name.strip('"')
+
     # todo We could check if condition is a key in the local args
     # if name not in template.template["Conditions"]:
     #     raise KeyError(
     #         f"Fn::Condition - Unable to find condition '{name}' in template."
     #     )
 
-    return f"local.{name}"
+    return LiteralType(f"local.{name}")
 
 
 def find_in_map(template: "TemplateConverter", values: Any):
@@ -325,20 +341,14 @@ def find_in_map(template: "TemplateConverter", values: Any):
 
     maps = local_block.arguments
 
-    if map_name not in maps:
-        raise KeyError(f"Unable to find {map_name} in locals block.")
+    if "mappings" not in maps:
+        raise Exception("No Mappings found in locals block.")
 
-    map = maps[map_name]
+    # Checking if the map names are valid doesn't work if the names were intrinsic functions/vars
 
-    if top_key not in map:
-        raise KeyError(f"Unable to find key {top_key} in map {map_name}.")
+    # Checking if the keys are valid doesn't work if the keys were intrinsic functions/vars
 
-    first_level = map[top_key]
-
-    if second_key not in first_level:
-        raise KeyError(f"Unable to find key {second_key} in map {map_name}.")
-
-    return f'local.{map_name}["{top_key}"]["{second_key}"]'
+    return LiteralType(f"local.mappings[{map_name}][{top_key}][{second_key}]")
 
 
 def get_att(template: "TemplateConverter", values: Any):
@@ -349,20 +359,68 @@ def get_att(template: "TemplateConverter", values: Any):
         values (Any): The values passed to the function.
 
     Raises:
-        TypeError: If values is not a list.
-        ValueError: If length of values is not 3.
-        TypeError: If the logicalNameOfResource and attributeName are not str.
-        KeyError: If the logicalNameOfResource is not found in the template.
+        TypeError: If values is not a String.
 
     Returns:
-        str: Terraform equivalent expression.
+        LiteralType: Terraform equivalent expression.
     """
 
-    if not isinstance(values, list):
-        raise TypeError(
-            f"Fn::GetAtt - The values must be a List, not {type(values).__name__}."
+    if isinstance(values, (str, StringType)):
+        return _get_att_string(template, values)
+
+    if isinstance(values, list):
+        return _get_att_list(template, values)
+
+    raise TypeError(
+        f"Fn::GetAtt - The value must be a String or List, not {type(values).__name__}."
+    )
+
+
+def _get_att_string(template: "TemplateConverter", values: Any):
+    """Converts AWS GetAtt intrinsic function to it's Terraform equivalent.
+
+    Args:
+        template (Configuration): The template being tested.
+        values (Any): The values passed to the function.
+
+    Raises:
+        ValueError: If the value doesn't contain a resource id and an attribute.
+
+    Returns:
+        LiteralType: Terraform equivalent expression.
+    """
+
+    if "." not in values:
+        raise ValueError(
+            "Fn::GetAtt - The value must contain a resource id and an attribute."
         )
 
+    parts = values.split(".")
+
+    resouce_id = parts[0]
+
+    attributes = ".".join(parts[1:])
+
+    result = _get_att_list(template, [resouce_id, attributes])
+
+    return result
+
+
+def _get_att_list(template: "TemplateConverter", values: Any):
+    """Converts AWS GetAtt intrinsic function to it's Terraform equivalent.
+
+    Args:
+        template (Configuration): The template being tested.
+        values (Any): The values passed to the function.
+
+    Raises:
+        ValueError: If the values length is not 2.
+        TypeError: If the values are not strings.
+
+    Returns:
+        LiteralType: Terraform equivalent expression.
+    """
+
     if not len(values) == 2:
         raise ValueError(
             (
@@ -379,8 +437,6 @@ def get_att(template: "TemplateConverter", values: Any):
             "Fn::GetAtt - logicalNameOfResource and attributeName must be String."
         )
 
-    cf_name = cf_name.strip('"')
-    cf_property = cf_property.strip('"')
     nested_prop: Optional[List[str]] = None
 
     if "." in cf_property:
@@ -401,6 +457,14 @@ def get_att(template: "TemplateConverter", values: Any):
     log.debug(f"Fn::GetAtt - Parsing attributes for {docs_path}")
     valid_arguments, valid_attributes = doc_file.parse_attributes(docs_path)
 
+    tf_name = cf2tf.convert.pascal_to_snake(cf_name)
+    tf_type = cf2tf.convert.create_resource_type(docs_path)
+
+    if nested_prop:
+        prop = f"{cf_property}.{'.'.join(nested_prop)}"
+        log.debug(f"Looking up nested attr {prop} for {tf_type}")
+        return nested_attr(tf_name, tf_type, cf_property, nested_prop)
+
     result = cf2tf.convert.matcher(cf_property, valid_arguments + valid_attributes, 50)
 
     if not result:
@@ -410,37 +474,40 @@ def get_att(template: "TemplateConverter", values: Any):
 
     attribute_name, _ = result
 
-    tf_name = cf2tf.convert.pascal_to_snake(cf_name)
-    tf_type = cf2tf.convert.create_resource_type(docs_path)
+    return LiteralType(f"{tf_type}.{tf_name}.{attribute_name}")
 
-    if nested_prop:
 
-        prop = f"{cf_property}.{'.'.join(nested_prop)}"
-        log.debug(
-            f"Looking up nested attr {attribute_name} from {cf_property} for {tf_type}"
+def nested_attr(tf_name: str, tf_type: str, cf_attr: str, nested_attr: List[str]):
+    if len(nested_attr) != 1:
+        raise ValueError(
+            f"Error parsing nested stack output for {cf_attr}.{'.'.join(nested_attr)}"
         )
-        return nested_attr(tf_name, tf_type, prop, attribute_name)
 
-    return f"{tf_type}.{tf_name}.{attribute_name}"
+    nested_attr_value = nested_attr[0]
+
+    if tf_type == "aws_cloudformation_stack":
+        return get_attr_nested_stack(tf_name, tf_type, cf_attr, nested_attr_value)
+
+    if tf_type == "aws_db_instance":
+        return get_attr_db_instance(tf_name, tf_type, cf_attr, nested_attr_value)
+
+    raise ValueError(
+        f"Unable to solve nested GetAttr {cf_attr} for {tf_name} and {tf_type}"
+    )
 
 
-def nested_attr(tf_name: str, tf_type: str, cf_prop: str, tf_attr: str):
+def get_attr_db_instance(tf_name: str, tf_type: str, cf_attr: str, nested_attr: str):
+    if cf_attr != "Endpoint":
+        raise ValueError(f"Unable to solve nested GetAttr {tf_name}")
 
-    if tf_type == "aws_cloudformation_stack" and tf_attr == "outputs":
-        return get_attr_nested_stack(tf_name, tf_type, cf_prop, tf_attr)
-
-    raise ValueError(f"Unable to solve nested GetAttr {cf_prop}")
+    return LiteralType(f"{tf_type}.{tf_name}.{nested_attr.lower()}")
 
 
-def get_attr_nested_stack(tf_name: str, tf_type: str, cf_property, tf_attr):
-    items = cf_property.split(".")
+def get_attr_nested_stack(tf_name: str, tf_type: str, cf_attr: str, nested_attr: str):
+    if cf_attr != "Outputs":
+        raise ValueError(f"Unable to solve nested GetAttr {cf_attr}")
 
-    if len(items) > 2:
-        raise ValueError(f"Error parsing nested stack output for {cf_property}")
-
-    _, stack_output_name = items
-
-    return f"{tf_type}.{tf_name}.{tf_attr}.{stack_output_name}"
+    return LiteralType(f"{tf_type}.{tf_name}.outputs.{nested_attr}")
 
 
 def get_azs(template: "TemplateConverter", region: Any):
@@ -465,30 +532,40 @@ def get_azs(template: "TemplateConverter", region: Any):
             f"Fn::GetAZs - The region must be a String, not {type(region).__name__}."
         )
 
-    region = region.strip('"')
+    region = region
 
     data = [
         data for data in template.post_proccess_blocks if isinstance(data, hcl2.Data)
     ]
 
     if not data:
-        az_data = hcl2.Data("available", "availability_zones", {"state": "available"})
+        az_data = hcl2.Data(
+            "available", "availability_zones", {"state": StringType("available")}
+        )
         template.post_proccess_blocks.insert(0, az_data)
 
-    return "data.aws_availability_zones.available.names"
+    return LiteralType("data.aws_availability_zones.available.names")
 
 
 # todo Handle functions that are not applicable to terraform.
 def import_value(template: "TemplateConverter", name: Any):
-    # I'm not sure how to handle this but I think if any exception is encountered while
-    # converting cf expressions to terraform, we should just comment out the entire line.
+    if not isinstance(name, str):
+        raise TypeError(
+            f"The import value type was expected to be string not {type(name)}"
+        )
 
-    # On second thought it probably makes sense to turn this into a input variable
-
-    raise Exception(
-        "Fn::Import Is Cloudformation native and unable to be converted to a Terraform expression."
+    var = hcl2.Variable(
+        name,
+        {
+            "description": StringType(
+                "This variable was an imported value in the Cloudformation Template."
+            )
+        },
     )
 
+    template.add_post_block(var)
+    return LiteralType(var.base_ref())
+
 
 def join(_tc: "TemplateConverter", values: Any):
     """Converts AWS Join intrinsic function to it's Terraform equivalent.
@@ -523,7 +600,7 @@ def join(_tc: "TemplateConverter", values: Any):
     items: Union[List[Any], str]
 
     if isinstance(values[0], str) and isinstance(values[1], (list, str)):
-        delimiter = values[0].strip('"')
+        delimiter = values[0]
         items = values[1]
     else:
         raise TypeError(
@@ -531,15 +608,15 @@ def join(_tc: "TemplateConverter", values: Any):
         )
 
     if isinstance(items, str):
-        return f'join("{delimiter}", {items})'
+        return LiteralType(f"join({delimiter}, {items})")
 
-    return f'join("{delimiter}", {_terraform_list(items)})'
+    return LiteralType(f"join({delimiter}, {_terraform_list(items)})")
 
 
 # todo I'm not sure this is that useful
 def _terraform_list(items: List[Any]):
-
-    items = [item for item in items]
+    # .join() doesn't call `_str_` on items
+    items = [str(item) for item in items]
 
     return f"[{', '.join(items)}]"
 
@@ -574,24 +651,23 @@ def select(_tc: "TemplateConverter", values: Any):
             )
         )
 
-    index: int
-    items: Union[List[Any], str]
+    index: int = values[0] if isinstance(values[0], int) else int(values[0])
+    items: Union[List[Any], str] = values[1]
 
-    if isinstance(values[0], int) and isinstance(values[1], (list, str)):
-        index = values[0]
-        items = values[1]
-    else:
+    if not isinstance(index, int) or not isinstance(items, (list, str)):
+        log.error(f"Index is type {type(index)} with value {index}")
+        log.error(f"Items is type {type(items)} with value {items}")
         raise TypeError(
             "Fn::Select - The first value must be a Number and the second a List or String."
         )
 
     if isinstance(items, str):
-        items = items.strip('"')
+        items = items
     else:
         items = _terraform_list(items)
 
     try:
-        return f"element({items}, {index})"
+        return LiteralType(f"element({items}, {index})")
     except IndexError:
         raise IndexError("Fn::Select - List size is smaller than the Index given.")
 
@@ -629,14 +705,14 @@ def split(_tc: "TemplateConverter", values: Any):
     source_string: str
 
     if isinstance(values[0], str) and isinstance(values[1], str):
-        delimiter = values[0].strip('"')
+        delimiter = values[0]
         source_string = values[1]
     else:
         raise TypeError(
             "Fn::Split-- The first value must be a String and the second a String."
         )
 
-    return f'split("{delimiter}", "{source_string}")'
+    return LiteralType(f'split("{delimiter}", {source_string})')
 
 
 def sub(template: "TemplateConverter", values: Any):
@@ -676,17 +752,27 @@ def sub_s(template: "TemplateConverter", value: str):
     """
 
     def replace_var(m):
-        var = m.group(2)
+        var = m.group(1)
+
+        if "." in var:
+            parts = var.split(".")
+
+            resouce_id = parts[0]
+
+            attributes = ".".join(parts[1:])
+
+            result = _get_att_list(template, [resouce_id, attributes])
+        else:
+            result = ref(template, var)
 
-        result = ref(template, var)
         return wrap_in_curlys(result)
 
-    reVar = r"(?!\$\{\!)\$(\w+|\{([^}]*)\})"
+    reVar = r"(?!\$\{\!)\$\{(\w+[^}]*)\}"
 
     if re.search(reVar, value):
-        return re.sub(reVar, replace_var, value).replace("${!", "${")
+        return StringType(re.sub(reVar, replace_var, value).replace("${!", "${"))
 
-    return value.replace("${!", "${")
+    return StringType(value.replace("${!", "${"))
 
 
 # todo This needs to create local variables in the template.
@@ -724,23 +810,34 @@ def sub_l(template: "TemplateConverter", values: List):
             "Fn::Sub - The first value must be a String and the second a Map."
         )
 
-    def replace_var(m):
-        var = m.group(2)
+    def replace_var(m) -> str:
+        var: str = m.group(1)
 
         if var in local_vars:
             result = local_vars[var]
             return wrap_in_curlys(result)
 
-        result = ref(template, var)
+        if "." in var:
+            parts = var.split(".")
+
+            resouce_id = parts[0]
+
+            attributes = ".".join(parts[1:])
+
+            result = _get_att_list(template, [resouce_id, attributes])
+        else:
+            result = ref(template, var)
 
         return wrap_in_curlys(result)
 
-    reVar = r"(?!\$\{\!)\$(\w+|\{([^}]*)\})"
+    reVar = r"(?!\$\{\!)\$\{(\w+[^}]*)\}"
 
     if re.search(reVar, source_string):
-        return re.sub(reVar, replace_var, source_string).replace("${!", "${")
+        return StringType(
+            re.sub(reVar, replace_var, source_string).replace("${!", "${")
+        )
 
-    return source_string.replace("${!", "${")
+    return StringType(source_string.replace("${!", "${"))
 
 
 # todo Transform is an AWS native capability with no Terraform equivalent expression.
@@ -768,63 +865,114 @@ def ref(template: "TemplateConverter", var_name: str):
     """
 
     if "AWS::" in var_name:
-
         return handle_pseduo_var(template, var_name)
 
     cf_param = template.resource_lookup(var_name, ["Parameters"])
 
     if cf_param:
         tf_name = cf2tf.convert.pascal_to_snake(var_name)
-        return f"var.{tf_name}"
+        return LiteralType(f"var.{tf_name}")
 
     cf_resource = template.resource_lookup(var_name, ["Resources"])
 
     if cf_resource:
         cf_resource_type = cf_resource.get("Type", "")
         docs_path = template.search_manager.find(cf_resource_type)
-        _, valid_attributes = doc_file.parse_attributes(docs_path)
+        valid_arguments, valid_attributes = doc_file.parse_attributes(docs_path)
         tf_name = cf2tf.convert.pascal_to_snake(var_name)
         tf_type = cf2tf.convert.create_resource_type(docs_path)
-        first_attr = next(iter(valid_attributes))
-        return f"{tf_type}.{tf_name}.{first_attr}"
+
+        first_attr = valid_attributes[0] if valid_attributes else valid_arguments[0]
+        conditional = cf_resource.get("Condition")
+
+        if conditional is not None:
+            tf_name = f"{tf_name}[0]"
+
+        return LiteralType(f"{tf_type}.{tf_name}.{first_attr}")
 
     raise ValueError(f"Fn::Ref - {var_name} is not a valid Resource or Parameter.")
 
 
-pseduo_values = {
-    "Region": hcl2.Data("current", "aws_region", valid_attributes=["name"]),
-    "AccountId": hcl2.Data(
-        "current", "aws_caller_identity", valid_attributes=["account_id"]
-    ),
-    "Partition": hcl2.Data("current", "aws_partition", valid_attributes=["partition"]),
+def region_pseduo(template: "TemplateConverter"):
+    block = hcl2.Data("current", "aws_region", valid_attributes=["name"])
+
+    template.add_post_block(block)
+
+    return block.ref()
+
+
+def account_id_pseduo(template: "TemplateConverter"):
+    block = hcl2.Data("current", "aws_caller_identity", valid_attributes=["account_id"])
+
+    template.add_post_block(block)
+
+    return block.ref()
+
+
+def partition_pseduo(template: "TemplateConverter"):
+    block = hcl2.Data("current", "aws_partition", valid_attributes=["partition"])
+
+    template.add_post_block(block)
+
+    return block.ref()
+
+
+def no_value_pseduo(_: "TemplateConverter"):
+    return NullType()
+
+
+def url_suffix_pseduo(template: "TemplateConverter"):
+    block = hcl2.Data("current", "aws_partition", valid_attributes=["partition"])
+
+    template.add_post_block(block)
+
+    return block.ref("dns_suffix")
+
+
+def stack_name_pseduo(template: "TemplateConverter"):
+    local_block = template.get_block_by_type(hcl2.Locals)
+
+    if not local_block:
+        local_block = hcl2.Locals({})
+        template.add_post_block(local_block)
+
+    local_block.arguments["stack_name"] = StringType(template.name)
+
+    return LiteralType("local.stack_name")
+
+
+def stack_id_pseduo(template: "TemplateConverter"):
+    local_block = template.get_block_by_type(hcl2.Locals)
+
+    if not local_block:
+        local_block = hcl2.Locals({})
+        template.add_post_block(local_block)
+
+    local_block.arguments["stack_id"] = LiteralType(f'uuidv5("dns", "{template.name}")')
+
+    return LiteralType("local.stack_id")
+
+
+pseduo_dispatch: Pseduo_Dispatch = {
+    "Region": region_pseduo,
+    "AccountId": account_id_pseduo,
+    "Partition": partition_pseduo,
+    "NoValue": no_value_pseduo,
+    "URLSuffix": url_suffix_pseduo,
+    "StackName": stack_name_pseduo,
+    "StackId": stack_id_pseduo,
 }
 
 
 def handle_pseduo_var(template: "TemplateConverter", pseudo_name: str):
-
     pseudo_type = pseudo_name.replace("AWS::", "")
 
-    if pseudo_type not in pseduo_values:
-
-        if pseudo_type == "NoValue":
-            return "null"
-
-        if pseudo_type == "URLSuffix":
-            block = pseduo_values["Partition"]
-
-            if block not in template.post_proccess_blocks:
-                template.post_proccess_blocks.insert(0, block)
-
-            return block.ref("dns_suffix")
-
+    if pseudo_type not in pseduo_dispatch:
         raise ValueError(f"Unable to process pseudo var {pseudo_name}.")
 
-    block = pseduo_values[pseudo_type]
+    pseduo_resolver: Pseduo_Resolver = pseduo_dispatch[pseudo_type]
 
-    if block not in template.post_proccess_blocks:
-        template.post_proccess_blocks.insert(0, block)
-
-    return "data.aws_region.current.name"
+    return pseduo_resolver(template)
 
 
 def wrap_in_curlys(input: str):
@@ -840,7 +988,7 @@ CONDITIONS: Dispatch = {
     "Fn::If": if_,
     "Fn::Not": not_,
     "Fn::Or": or_,
-    "Fn::Condition": condition,
+    "Condition": condition,
 }
 
 # These are all the json keys for intrinsic functions
@@ -879,7 +1027,12 @@ ALLOWED_NESTED_CONDITIONS: Dispatch = {
 # functions that are allowed to be nested inside it.
 ALLOWED_FUNCTIONS: Dict[str, Dispatch] = {
     "Fn::And": ALLOWED_NESTED_CONDITIONS,
-    "Fn::Equals": ALLOWED_NESTED_CONDITIONS,
+    "Fn::Equals": {
+        **ALLOWED_NESTED_CONDITIONS,
+        "Fn::Join": join,
+        "Fn::Select": select,
+        "Fn::Sub": sub,
+    },
     "Fn::If": {
         "Fn::Base64": base64,
         "Fn::FindInMap": find_in_map,
@@ -890,14 +1043,16 @@ ALLOWED_FUNCTIONS: Dict[str, Dispatch] = {
         "Fn::Select": select,
         "Fn::Sub": sub,
         "Ref": ref,
+        "Fn::Split": split,
     },
     "Fn::Not": ALLOWED_NESTED_CONDITIONS,
     "Fn::Or": ALLOWED_NESTED_CONDITIONS,
-    "Fn::Condition": {},  # Only allows strings
+    "Condition": {},  # Only allows strings
     "Fn::Base64": ALL_FUNCTIONS,
     "Fn::Cidr": {
         "Fn::Select": select,
         "Ref": ref,
+        "Fn::GetAtt": get_att,
     },
     "Fn::FindInMap": {
         "Fn::FindInMap": find_in_map,
@@ -931,6 +1086,7 @@ ALLOWED_FUNCTIONS: Dict[str, Dispatch] = {
         "Ref": ref,
     },
     "Fn::Select": {
+        "Fn::Cidr": cidr,
         "Fn::FindInMap": find_in_map,
         "Fn::GetAtt": get_att,
         "Fn::GetAZs": get_azs,
